@@ -1,12 +1,14 @@
 from django.apps import AppConfig
 from django.utils.translation import ugettext_lazy as _
 
+from cms.utils.setup import setup
+
 
 class CMSConfig(AppConfig):
     name = 'cms'
     verbose_name = _("django CMS")
 
     def ready(self):
-        from cms.models import validate_dependencies, validate_settings
-        validate_dependencies()
-        validate_settings()
\ No newline at end of file
+        setup()
+        from cms.plugin_pool import plugin_pool
+        plugin_pool.set_plugin_meta()
