@@ -7,7 +7,6 @@ from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.db import models, migrations
 import django.utils.timezone
-from django.utils.translation import ugettext_lazy as _
 
 User = get_user_model()
 
@@ -52,9 +51,9 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='Placeholder',
             fields=[
-                ('id', models.AutoField(primary_key=True, verbose_name=_('ID'), auto_created=True, serialize=False)),
-                ('slot', models.CharField(db_index=True, max_length=50, verbose_name=_('slot'), editable=False)),
-                ('default_width', models.PositiveSmallIntegerField(null=True, verbose_name=_('width'), editable=False)),
+                ('id', models.AutoField(primary_key=True, verbose_name='ID', auto_created=True, serialize=False)),
+                ('slot', models.CharField(db_index=True, max_length=50, verbose_name='slot', editable=False)),
+                ('default_width', models.PositiveSmallIntegerField(null=True, verbose_name='width', editable=False)),
             ],
             options={
             },
@@ -96,12 +95,12 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='StaticPlaceholder',
             fields=[
-                ('id', models.AutoField(primary_key=True, verbose_name=_('ID'), auto_created=True, serialize=False)),
-                ('name', models.CharField(max_length=255, default='', help_text='Descriptive name to identify this static placeholder. Not displayed to users.', blank=True, verbose_name=_('static placeholder name'))),
-                ('code', models.CharField(max_length=255, verbose_name=_('placeholder code'), help_text='To render the static placeholder in templates.', blank=True)),
+                ('id', models.AutoField(primary_key=True, verbose_name='ID', auto_created=True, serialize=False)),
+                ('name', models.CharField(max_length=255, default='', help_text='Descriptive name to identify this static placeholder. Not displayed to users.', blank=True, verbose_name='static placeholder name')),
+                ('code', models.CharField(max_length=255, verbose_name='placeholder code', help_text='To render the static placeholder in templates.', blank=True)),
                 ('dirty', models.BooleanField(default=False, editable=False)),
-                ('creation_method', models.CharField(max_length=20, default='code', blank=True, verbose_name=_('creation_method'), choices=cms.models.static_placeholder.StaticPlaceholder.CREATION_METHODS)),
-                ('draft', cms.models.fields.PlaceholderField(null=True, to='cms.Placeholder', verbose_name=_('placeholder content'), related_name='static_draft', slotname=cms.models.static_placeholder.static_slotname, editable=False)),
+                ('creation_method', models.CharField(max_length=20, default='code', blank=True, verbose_name='creation_method', choices=cms.models.static_placeholder.StaticPlaceholder.CREATION_METHODS)),
+                ('draft', cms.models.fields.PlaceholderField(null=True, to='cms.Placeholder', verbose_name='placeholder content', related_name='static_draft', slotname=cms.models.static_placeholder.static_slotname, editable=False)),
                 ('public', cms.models.fields.PlaceholderField(null=True, to='cms.Placeholder', slotname=cms.models.static_placeholder.static_slotname, related_name='static_public', editable=False)),
                 ('site', models.ForeignKey(null=True, to='sites.Site', blank=True)),
             ],
@@ -118,21 +117,21 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='Title',
             fields=[
-                ('id', models.AutoField(primary_key=True, verbose_name=_('ID'), auto_created=True, serialize=False)),
-                ('language', models.CharField(db_index=True, max_length=15, verbose_name=_('language'))),
-                ('title', models.CharField(max_length=255, verbose_name=_('title'))),
-                ('page_title', models.CharField(max_length=255, null=True, help_text='overwrite the title (html title tag)', blank=True, verbose_name=_('title'))),
-                ('menu_title', models.CharField(max_length=255, null=True, help_text='overwrite the title in the menu', blank=True, verbose_name=_('title'))),
-                ('meta_description', models.TextField(max_length=155, null=True, help_text='The text displayed in search engines.', blank=True, verbose_name=_('description'))),
-                ('slug', models.SlugField(max_length=255, verbose_name=_('slug'))),
-                ('path', models.CharField(db_index=True, max_length=255, verbose_name=_('Path'))),
-                ('has_url_overwrite', models.BooleanField(db_index=True, default=False, editable=False, verbose_name=_('has url overwrite'))),
-                ('redirect', models.CharField(max_length=255, null=True, blank=True, verbose_name=_('redirect'))),
-                ('creation_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name=_('creation date'), editable=False)),
-                ('published', models.BooleanField(default=False, verbose_name=_('is published'))),
+                ('id', models.AutoField(primary_key=True, verbose_name='ID', auto_created=True, serialize=False)),
+                ('language', models.CharField(db_index=True, max_length=15, verbose_name='language')),
+                ('title', models.CharField(max_length=255, verbose_name='title')),
+                ('page_title', models.CharField(max_length=255, null=True, help_text='overwrite the title (html title tag)', blank=True, verbose_name='title')),
+                ('menu_title', models.CharField(max_length=255, null=True, help_text='overwrite the title in the menu', blank=True, verbose_name='title')),
+                ('meta_description', models.TextField(max_length=155, null=True, help_text='The text displayed in search engines.', blank=True, verbose_name='description')),
+                ('slug', models.SlugField(max_length=255, verbose_name='slug')),
+                ('path', models.CharField(db_index=True, max_length=255, verbose_name='Path')),
+                ('has_url_overwrite', models.BooleanField(default=False, verbose_name='has URL overwrite', db_index=True, editable=False)),
+                ('redirect', models.CharField(max_length=255, null=True, blank=True, verbose_name='redirect')),
+                ('creation_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='creation date', editable=False)),
+                ('published', models.BooleanField(default=False, verbose_name='is published')),
                 ('publisher_is_draft', models.BooleanField(db_index=True, default=True, editable=False)),
                 ('publisher_state', models.SmallIntegerField(db_index=True, default=0, editable=False)),
-                ('page', models.ForeignKey(to='cms.Page', verbose_name=_('page'), related_name='title_set')),
+                ('page', models.ForeignKey(to='cms.Page', verbose_name='page', related_name='title_set')),
                 ('publisher_public', models.OneToOneField(null=True, to='cms.Title', related_name='publisher_draft', editable=False)),
             ],
             options={
@@ -146,8 +145,8 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='UserSettings',
             fields=[
-                ('id', models.AutoField(primary_key=True, verbose_name=_('ID'), auto_created=True, serialize=False)),
-                ('language', models.CharField(max_length=10, choices=settings.LANGUAGES, help_text='The language for the admin interface and toolbar', verbose_name=_('Language'))),
+                ('id', models.AutoField(primary_key=True, verbose_name='ID', auto_created=True, serialize=False)),
+                ('language', models.CharField(max_length=10, choices=settings.LANGUAGES, help_text='The language for the admin interface and toolbar', verbose_name='Language')),
                 ('clipboard', models.ForeignKey(null=True, to='cms.Placeholder', blank=True, editable=False)),
                 ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL, unique=True, related_name='djangocms_usersettings', editable=False)),
             ],
