@@ -58,7 +58,8 @@ def pre_save_group(instance, raw, **kwargs):
 
 
 def pre_delete_group(instance, **kwargs):
-    for user in instance.user_set.all():
+    user_set = getattr(instance, user_related_name)
+    for user in user_set.all():
         clear_user_permission_cache(user)
 
 
