@@ -7,6 +7,7 @@ from cms.utils.compat.dj import get_user_model
 
 if getattr(OriginalUser._meta, 'swapped', False):
     class UserAdmin(OriginalUserAdmin):
-        pass
+        list_display = ('username', 'email', 'get_full_name', 'is_staff')
+        search_fields = ('username', 'email',)
 
-    admin.site.register(get_user_model(), UserAdmin)
\ No newline at end of file
+    admin.site.register(get_user_model(), UserAdmin)
