@@ -7,14 +7,14 @@ from django.db import models, migrations
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('cms', '__first__'),
+        ('cms', '0001_initial'),
     ]
 
     operations = [
         migrations.CreateModel(
             name='TestPluginModel',
             fields=[
-                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
+                ('cmsplugin_ptr', models.OneToOneField(primary_key=True, to='cms.CMSPlugin', auto_created=True, parent_link=True, serialize=False)),
             ],
             options={
                 'abstract': False,
@@ -24,20 +24,20 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='TestPluginModel2',
             fields=[
-                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
+                ('cmsplugin_ptr', models.OneToOneField(primary_key=True, to='cms.CMSPlugin', auto_created=True, parent_link=True, serialize=False)),
             ],
             options={
-                'db_table': b'meta_testpluginmodel2',
+                'db_table': 'meta_testpluginmodel2',
             },
             bases=('cms.cmsplugin',),
         ),
         migrations.CreateModel(
             name='TestPluginModel4',
             fields=[
-                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
+                ('cmsplugin_ptr', models.OneToOneField(primary_key=True, to='cms.CMSPlugin', auto_created=True, parent_link=True, serialize=False)),
             ],
             options={
-                'db_table': b'or_another_4',
+                'db_table': 'or_another_4',
             },
             bases=('cms.cmsplugin',),
         ),
