@@ -2,7 +2,7 @@
 from __future__ import with_statement
 
 from cms.tests.menu_page_viewperm import ViewPermissionTests
-from cms.compat import get_user_model
+from cms.utils.compat.dj import get_user_model
 
 __all__ = [
     'ViewPermissionComplexMenuStaffNodeTests',
