@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-from django.conf import settings
+from cms.utils.compat.dj import is_installed
+
 
 # modify reversions to match our needs if required...
-
-
 def reversion_register(model_class, fields=None, follow=(), format="json", exclude_fields=None):
     """CMS interface to reversion api - helper function. Registers model for 
     reversion only if reversion is available.
@@ -13,7 +12,7 @@ def reversion_register(model_class, fields=None, follow=(), format="json", exclu
     """
     
     # reversion's merely recommended, not required
-    if not 'reversion' in settings.INSTALLED_APPS:
+    if not is_installed('reversion'):
         return
     
     if fields and exclude_fields:
@@ -46,8 +45,12 @@ def make_revision_with_plugins(obj, user=None, message=None):
     revision_context = reversion.revision_context_manager
     
     cls = obj.__class__
-    
-    if cls in revision_manager._registered_models:
+    if hasattr(revision_manager, '_registration_key_for_model'):
+        model_key = revision_manager._registration_key_for_model(cls)
+    else:
+        model_key = cls
+
+    if model_key in revision_manager._registered_models:
         
         placeholder_relation = find_placeholder_relation(obj)
 
